package xyz.zhouxy.plusone.jdbc;

import org.springframework.jdbc.core.namedparam.BeanPropertySqlParameterSource;
import org.springframework.jdbc.core.namedparam.SqlParameterSource;
import org.springframework.lang.Nullable;

import xyz.zhouxy.plusone.commons.base.IWithCode;
import xyz.zhouxy.plusone.commons.base.IWithIntCode;

/**
 * 扩展了 {@link BeanPropertySqlParameterSource}，在将 POJO 转换为
 * {@link org.springframework.jdbc.core.namedparam.SqlParameterSource} 时，
 * 使用 {@link Enum#ordinal()} 将枚举转换成整数。
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 *
 * @see SqlParameterSource
 * @see BeanPropertySqlParameterSource
 * @see org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate
 * @see Enum
 */
public class BeanPropertyParamSource extends BeanPropertySqlParameterSource {

    public BeanPropertyParamSource(Object object) {
        super(object);
    }

    @Override
    @Nullable
    public Object getValue(String paramName) throws IllegalArgumentException {
        Object value = super.getValue(paramName);
        if (value instanceof Enum<?> e) {
            if (value instanceof IWithCode<?> c) {
                return c.getCode();
            }
            if (value instanceof IWithIntCode c) {
                return c.getCode();
            }
            return e.ordinal();
        }
        return value;
    }
}
