package xyz.zhouxy.plusone.jdbc;

import org.springframework.context.ApplicationContext;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;

import xyz.zhouxy.plusone.spring.SpringContextHolder;

/**
 * 通过静态方法获取 Spring 容器中的 {@link JdbcTemplate} 和
 * {@link NamedParameterJdbcTemplate} 对象。
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 * @see JdbcTemplate
 * @see NamedParameterJdbcTemplate
 */
public final class JdbcFactory {

    private static final ApplicationContext SPRING_APPLICATION_CONTEXT = SpringContextHolder.getContext();
    private static final JdbcTemplate JDBC_TEMPLATE = SPRING_APPLICATION_CONTEXT.getBean(JdbcTemplate.class);
    private static final NamedParameterJdbcTemplate NAMED_PARAMETER_JDBC_TEMPLATE = SPRING_APPLICATION_CONTEXT.getBean(NamedParameterJdbcTemplate.class);

    private JdbcFactory() {
        throw new IllegalStateException("Utility class");
    }

    public static JdbcTemplate getJdbcTemplate() {
        return JDBC_TEMPLATE;
    }

    public static NamedParameterJdbcTemplate getNamedParameterJdbcTemplate() {
        return NAMED_PARAMETER_JDBC_TEMPLATE;
    }
}
